# LabelPrint
### Automated barcode label generation and printing in Python

Note: Detailed usage coming soon.

## Warning

This package only works on Windows at the moment. With some minor rework, it could work on Linux too, that's just not a priority for my purposes at the moment.